@@ -20,7 +20,6 @@ OC.L10N.register(
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "can edit" : "kan redigere",
-    "Address book name" : "Adresseboksnavn",
     "First name" : "Fornavn",
     "Last name" : "Etternavn",
     "Display name" : "Visningsnavn",
@@ -109,7 +108,6 @@ OC.L10N.register(
     "Male" : "Dame",
     "None" : "Ingen",
     "Unknown" : "Ukjent",
-    "Timezone" : "Tidssone",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"]
 },
 "nplurals=2; plural=(n != 1);");
